@@ -1,4 +1,4 @@
-"""Release management utilities for Python Release Master."""
+"""Release management for Python packages."""
 
 import logging
 import os
@@ -8,16 +8,20 @@ import subprocess
 from pathlib import Path
 from typing import List, Optional, Dict, Any, Tuple
 
-from python_release_master.core.config import Config
-from python_release_master.core.changelog import generate_changelog
-from python_release_master.core.validation import validate_environment, ensure_package_structure, validate_package
 from python_release_master.core.ai_utils import (
     analyze_changes_for_version_bump,
-    generate_release_title,
     generate_changelog_with_ai,
+    generate_release_title,
+)
+from python_release_master.core.config import Config, load_config
+from python_release_master.core.changelog import generate_changelog
+from python_release_master.core.validation import (
+    validate_environment,
+    ensure_package_structure,
+    validate_package,
 )
 from python_release_master.core.logger import logger
-from python_release_master.core.errors import ReleaseError, ErrorCode
+from python_release_master.core.errors import ErrorCode, ReleaseError
 from python_release_master.core.validation_manager import ValidationManager
 
 def create_github_repository(config: Config) -> None:
@@ -149,9 +153,8 @@ def create_release(config: Config, workspace_dir: Optional[Path] = None) -> None
         
         # Step 5: Bump version
         logger.start_operation("Bumping version...")
-        bump_version(bump_type, config.version.files)
-        version = get_current_version(config.version.files[0])
-        logger.success(f"Bumped version to {version}")
+        new_version = bump_version(bump_type)
+        logger.success(f"Bumped version to {new_version}")
         
         # Step 6: Generate changelog
         logger.start_operation("Generating changelog...")
@@ -177,16 +180,11 @@ def create_release(config: Config, workspace_dir: Optional[Path] = None) -> None
         
         # Step 7: Generate release title
         logger.start_operation("Generating release title...")
-        logger.api_call("OpenAI", "chat/completions", {
-            "model": config.changelog.ai.model,
-            "temperature": config.changelog.ai.temperature,
-            "messages": [{"role": "system", "content": "Generate release title"}]
-        })
         title = generate_release_title(
-            version,
+            new_version,
             changelog_text,
             model=config.changelog.ai.model,
-            temperature=config.changelog.ai.temperature
+            temperature=config.changelog.ai.temperature,
         )
         logger.success(f"Generated release title: {title}")
         
@@ -206,12 +204,12 @@ def create_release(config: Config, workspace_dir: Optional[Path] = None) -> None
         # Step 10: Create Git release
         if config.git.release.enabled:
             logger.start_operation("Creating Git release...")
-            create_git_release(version, title, changelog_text, config)
+            create_git_release(new_version, title, changelog_text, config)
             logger.success("Git release created")
         
         # Final success message
         logger.panel(
-            f"Successfully created release {version}\n\n"
+            f"Successfully created release {new_version}\n\n"
             f"Title: {title}\n\n"
             f"Changelog:\n{changelog_text}",
             "Release Complete",
@@ -268,51 +266,62 @@ def publish_package(config: Config) -> None:
             context={"command": " ".join(cmd), "exit_code": e.returncode}
         )
 
-def bump_version(bump_type: str, version_files: List[str]) -> None:
-    """Bump version in specified files.
+def bump_version(bump_type: str) -> str:
+    """Bump the version number.
     
     Args:
         bump_type: Type of version bump (major, minor, patch)
-        version_files: List of files containing version strings
+    
+    Returns:
+        str: New version number
     
     Raises:
         ReleaseError: If version bump fails
     """
-    current_version = get_current_version(version_files[0])
-    if not current_version:
-        raise ReleaseError(
-            code=ErrorCode.VERSION_NOT_FOUND,
-            message="Could not determine current version"
-        )
-    
-    # Parse version components
-    match = re.match(r"(\d+)\.(\d+)\.(\d+)", current_version)
-    if not match:
-        raise ReleaseError(
-            code=ErrorCode.VERSION_INVALID,
-            message=f"Invalid version format: {current_version}"
-        )
-    
-    major, minor, patch = map(int, match.groups())
-    
-    # Calculate new version
-    if bump_type == "major":
-        new_version = f"{major + 1}.0.0"
-    elif bump_type == "minor":
-        new_version = f"{major}.{minor + 1}.0"
-    elif bump_type == "patch":
-        new_version = f"{major}.{minor}.{patch + 1}"
-    else:
-        raise ReleaseError(
-            code=ErrorCode.VERSION_INVALID,
-            message=f"Invalid bump type: {bump_type}"
-        )
-    
-    # Update version in files
-    for file in version_files:
-        logger.command(["sed", "-i", f"s/{current_version}/{new_version}/g", file])
-        update_version_in_file(file, current_version, new_version)
-        logger.success(f"Updated version in {file}")
+    try:
+        # Get current version from pyproject.toml
+        with open("pyproject.toml", "r") as f:
+            content = f.read()
+            match = re.search(r'version\s*=\s*"(\d+\.\d+\.\d+)"', content)
+            if not match:
+                raise ReleaseError(
+                    ErrorCode.VERSION_NOT_FOUND,
+                    "Version not found in pyproject.toml"
+                )
+            current_version = match.group(1)
+        
+        # Parse version and bump
+        major, minor, patch = map(int, current_version.split("."))
+        if bump_type == "major":
+            new_version = f"{major + 1}.0.0"
+        elif bump_type == "minor":
+            new_version = f"{major}.{minor + 1}.0"
+        else:  # patch
+            new_version = f"{major}.{minor}.{patch + 1}"
+        
+        # Update version in pyproject.toml
+        with open("pyproject.toml", "r") as f:
+            content = f.read()
+        
+        new_content = content.replace(f'version = "{current_version}"', f'version = "{new_version}"')
+        
+        with open("pyproject.toml", "w") as f:
+            f.write(new_content)
+        
+        logger.success("Updated version in pyproject.toml")
+        
+        # Clean dist directory and rebuild with new version
+        clean_dist()
+        validate_package(load_config())
+        
+        return new_version
+    except Exception as e:
+        if not isinstance(e, ReleaseError):
+            raise ReleaseError(
+                ErrorCode.VERSION_BUMP_FAILED,
+                str(e)
+            ) from e
+        raise e
 
 def get_current_version(version_file: str) -> str:
     """Get current version from file.
@@ -386,19 +395,25 @@ def update_version_in_file(file: str, old_version: str, new_version: str) -> Non
 def clean_dist() -> None:
     """Clean the dist directory.
     
+    This removes all build artifacts from previous builds to ensure a clean state.
+    
     Raises:
         ReleaseError: If cleaning fails
     """
     dist_dir = Path("dist")
+    
     try:
+        # Remove the entire dist directory if it exists
         if dist_dir.exists():
-            logger.command(["rm", "-rf", "dist"])
             shutil.rmtree(dist_dir)
+        
+        # Create a fresh dist directory
         dist_dir.mkdir(exist_ok=True)
+        logger.success("Cleaned dist directory")
     except Exception as e:
         raise ReleaseError(
-            code=ErrorCode.BUILD_FAILED,
-            message=f"Failed to clean dist directory: {e}",
+            ErrorCode.BUILD_FAILED,
+            f"Failed to clean dist directory: {e}",
             context={"directory": str(dist_dir)}
         )
 
